==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/WorkspaceConnectionSharedAccessSignatureArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.WorkspaceConnectionSharedAccessSignatureArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property sas
 */
public data class WorkspaceConnectionSharedAccessSignatureArgs(
    public val sas: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.WorkspaceConnectionSharedAccessSignatureArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.WorkspaceConnectionSharedAccessSignatureArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.WorkspaceConnectionSharedAccessSignatureArgs.builder()
            .sas(sas?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkspaceConnectionSharedAccessSignatureArgs].
 */
@PulumiTagMarker
public class WorkspaceConnectionSharedAccessSignatureArgsBuilder internal constructor() {
    private var sas: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("woaicbxfgaulkiys")
    public suspend fun sas(`value`: Output<String>) {
        this.sas = value
    }

    /**
     * @param value
     */
    @JvmName("aggnbtmurvlrmnyt")
    public suspend fun sas(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sas = mapped
    }

    internal fun build(): WorkspaceConnectionSharedAccessSignatureArgs =
        WorkspaceConnectionSharedAccessSignatureArgs(
            sas = sas,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/WorkspaceConnectionSharedAccessSignatureArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.WorkspaceConnectionSharedAccessSignatureArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property sas
 */
public data class WorkspaceConnectionSharedAccessSignatureArgs(
    public val sas: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.WorkspaceConnectionSharedAccessSignatureArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.WorkspaceConnectionSharedAccessSignatureArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.WorkspaceConnectionSharedAccessSignatureArgs.builder()
            .sas(sas?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkspaceConnectionSharedAccessSignatureArgs].
 */
@PulumiTagMarker
public class WorkspaceConnectionSharedAccessSignatureArgsBuilder internal constructor() {
    private var sas: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("dmmdorjercctmeef")
    public suspend fun sas(`value`: Output<String>) {
        this.sas = value
    }

    /**
     * @param value
     */
    @JvmName("qqtulrusctwacxas")
    public suspend fun sas(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sas = mapped
    }

    internal fun build(): WorkspaceConnectionSharedAccessSignatureArgs =
        WorkspaceConnectionSharedAccessSignatureArgs(
            sas = sas,
        )
}
